@@ -147,7 +147,8 @@ def GenerateLdsoWrapper(root, path, interp, libpaths=()):
   """
   basedir = os.path.dirname(path)
   interp_dir, interp_name = os.path.split(interp)
-  libpaths = dedupe([interp_dir] + list(libpaths))
+  # Add ldso interpreter dir to end of libpaths as a fallback library path.
+  libpaths = dedupe(list(libpaths) + [interp_dir])
   replacements = {
       'interp': os.path.join(os.path.relpath(interp_dir, basedir),
                              interp_name),
@@ -195,7 +196,7 @@ def ParseLdPaths(str_ldpaths, root='', path=None):
   """
   ldpaths = []
   for ldpath in str_ldpaths.split(':'):
-    if ldpath == '':
+    if not ldpath:
       # The ldso treats "" paths as $PWD.
       ldpath = os.getcwd()
     elif '$ORIGIN' in ldpath:
